@@ -1,21 +1,19 @@
-'''
-This file is a part of Arjuna
-Copyright 2015-2020 Rahul Verma
+# This file is a part of Arjuna
+# Copyright 2015-2020 Rahul Verma
 
-Website: www.RahulVerma.net
+# Website: www.RahulVerma.net
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 
-  http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-'''
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import re
 
@@ -150,7 +148,7 @@ class With(metaclass=_WithXMetaClass):
             rmap["value"]
             return rmap
         except:
-            raise Exception("Name and value must be supplied for {}. Got: {}".format(rlvalue, rltype))
+            raise Exception("Name and value must be supplied. Got: {}".format(map))
 
     @classmethod
     def _attr(cls, map):
@@ -192,10 +190,6 @@ class With(metaclass=_WithXMetaClass):
     def value(cls, value, tag=None):
         return With(WithType.VALUE, value)
 
-    @classmethod
-    def type(cls, type):
-        return With(WithType.TYPE, type)
-
     @classmethod
     def point(cls, point):
         return With(WithType.POINT, point)
