@@ -117,6 +117,7 @@ class CreateProject(Command):
         (FileObjectType.DIR, "data/reference"),
         (FileObjectType.DIR, "data/reference/contextual"),
         (FileObjectType.DIR, "data/reference/indexed"),
+        (FileObjectType.DIR, "data/file"),
         (FileObjectType.DIR, "l10n"),
         (FileObjectType.DIR, "guiauto"),
         (FileObjectType.DIR, "guiauto/driver"),
@@ -132,6 +133,8 @@ class CreateProject(Command):
         (FileObjectType.FILE, "test/__init__.py"),
         (FileObjectType.DIR, "test/pkg"),
         (FileObjectType.FILE, "test/pkg/__init__.py"),
+        (FileObjectType.DIR, "tools"),
+        (FileObjectType.DIR, "tools/bmproxy"),
         (FileObjectType.DIR, "lib"),
         (FileObjectType.FILE, "lib/__init__.py"),
         (FileObjectType.FILE, "lib/resource.py")
@@ -183,7 +186,7 @@ class CreateProject(Command):
             f = open(get_proj_target_path("test/conftest.py"), "w")
             f.write(contents)
             f.close()
-            for d in ["data/source", "l10n/excel", "l10n/json", "data/reference/excel_row", "data/reference/excel_column", "guiauto/namespace"]:
+            for d in ["data/source", "data/file", "data/reference/contextual", "data/reference/indexed", "l10n", "guiauto/namespace", "tools/bmproxy"]:
                 copy_file("../../res/placeholder.txt", d + "/placeholder.txt")
             for os_name in ["mac", "windows", "linux"]:
                 copy_file("../../res/placeholder.txt", "guiauto/driver/{}/placeholder.txt".format(os_name))
@@ -234,6 +237,9 @@ class __RunCommand(Command):
     def pop_command_args(self, arg_dict):
         pass
 
+    def exit(self):
+        from arjuna import Arjuna
+        Arjuna.exit()
 
 class RunProject(__RunCommand):
     def __init__(self, subparsers, parents):
@@ -246,6 +252,7 @@ class RunProject(__RunCommand):
         session = Arjuna.get_test_session()
         session.load_tests(dry_run=self.dry_run, ref_conf_name=self.ref_conf_name)
         session.run()
+        super().exit()
 
 
 class RunSession(__RunCommand):
@@ -258,6 +265,7 @@ class RunSession(__RunCommand):
         session = Arjuna.get_test_session()
         session.load_tests(dry_run=self.dry_run, ref_conf_name=self.ref_conf_name)
         session.run()
+        super().exit()
 
 class RunStage(__RunCommand):
     def __init__(self, subparsers, parents):
@@ -270,6 +278,7 @@ class RunStage(__RunCommand):
         session = Arjuna.get_test_session()
         session.load_tests_for_stage(stage_name=self.__stage_name, dry_run=self.dry_run, ref_conf_name=self.ref_conf_name)
         session.run()
+        super().exit()
 
     def pop_command_args(self, arg_dict):
         self.__stage_name = arg_dict.pop("stage_name")
@@ -285,6 +294,7 @@ class RunGroup(__RunCommand):
         session = Arjuna.get_test_session()
         session.load_tests_for_group(group_name=self.__group_name, dry_run=self.dry_run, ref_conf_name=self.ref_conf_name)
         session.run()
+        super().exit()
 
     def pop_command_args(self, arg_dict):
         self.__group_name = arg_dict.pop("group_name")
@@ -305,6 +315,7 @@ class RunSelected(__RunCommand):
         session = Arjuna.get_test_session()
         session.load_tests(rules=self.__rules, dry_run=self.dry_run, ref_conf_name=self.ref_conf_name)
         session.run()
+        super().exit()
 
     def pop_command_args(self, arg_dict):
         from arjuna.engine.session.group import TestGroup
